@@ -28,7 +28,7 @@
 # Phone Book Window
 
 proc fax_phonebook {} {
-    global fax
+    global fax m
 
     # Name of this window
 
@@ -42,40 +42,42 @@ proc fax_phonebook {} {
 
     frame $wn.0 -bd 10
     label $wn.0.l -text "TkFax: Fax Number Book" -padx 20 -pady 4 -relief ridge
-    pack $wn.0.l -side left -fill x -expand yes
+    pack $wn.0.l -side top -fill x -expand yes
 
     # List of groups
 
     frame $wn.g
     frame $wn.g.l
-    label $wn.g.l.1 -text "Group Name" -width 20 -anchor w
-    label $wn.g.l.2 -text "Description" -width 40 -anchor w -padx 4
+    label $wn.g.l.1 -text $m(group_name) -width 20 -anchor w
+    label $wn.g.l.2 -text $m(description) -width 40 -anchor w -padx 4
     pack $wn.g.l.1 $wn.g.l.2 -side left -fill x
     text $wn.g.t -width 60 -height 5 \
          -tabs {5c left 15c left} -wrap none \
          -xscroll "$wn.g.x set" -yscroll "$wn.g.y set" \
          -relief sunken -font $fax(f1)
+    mscroll $wn.g.t
     scrollbar $wn.g.x -command "$wn.g.t xview" -orient horizontal
     scrollbar $wn.g.y -command "$wn.g.t yview"
-    grid $wn.g.l  -row 0 -column 0 -rowspan 1 -columnspan 2 -sticky news
+    grid $wn.g.l  -row 0 -column 0 -rowspan 1 -columnspan 2 -sticky ew
     grid $wn.g.t  -row 1 -column 0 -rowspan 1 -columnspan 1 -sticky news
-    grid $wn.g.y  -row 1 -column 1 -rowspan 1 -columnspan 1 -sticky news
-    grid $wn.g.x  -row 2 -column 0 -rowspan 1 -columnspan 1 -sticky news
-
+    grid $wn.g.y  -row 1 -column 1 -rowspan 1 -columnspan 1 -sticky ns
+    grid $wn.g.x  -row 2 -column 0 -rowspan 1 -columnspan 1 -sticky ew
+    grid rowconfigure $wn.g 1 -weight 1
+    grid columnconfigure $wn.g 0 -weight 1
     # Group Entries
 
     frame $wn.j -bd 2 -relief ridge
-    label $wn.j.1 -text "Group Name"  -anchor e -width 10
-    label $wn.j.2 -text "Description" -anchor e -width 10
+    label $wn.j.1 -text $m(group_name)  -anchor e -width 10
+    label $wn.j.2 -text $m(description) -anchor e -width 10
     entry $wn.j.3 -textvariable fax(tmpgroupname) -width 20 \
           -font $fax(f1) -fg $fax(c1)
     entry $wn.j.4 -textvariable fax(tmpgroupdescription) -width 40 \
           -font $fax(f1) -fg $fax(c1)
-    button $wn.j.a -text Clear  -command fax_pbook_group_clear \
+    button $wn.j.a -text $m(clear)  -command fax_pbook_group_clear \
            -width 6 -pady 0
-    button $wn.j.b -text Add    -command fax_pbook_group_add \
+    button $wn.j.b -text $m(add)    -command fax_pbook_group_add \
            -width 6 -pady 0
-    button $wn.j.c -text Remove -command fax_pbook_group_remove \
+    button $wn.j.c -text $m(remove) -command fax_pbook_group_remove \
            -width 6 -pady 0
     grid $wn.j.1  -row 1 -column 1 -rowspan 1 -columnspan 1 -sticky news
     grid $wn.j.2  -row 2 -column 1 -rowspan 1 -columnspan 1 -sticky news
@@ -84,6 +86,7 @@ proc fax_phonebook {} {
     grid $wn.j.a  -row 1 -column 5 -rowspan 1 -columnspan 1 -sticky news
     grid $wn.j.b  -row 1 -column 6 -rowspan 1 -columnspan 1 -sticky news
     grid $wn.j.c  -row 2 -column 6 -rowspan 1 -columnspan 1 -sticky news
+    grid columnconfigure $wn.j 2 -weight 1
 
     # spare space
 
@@ -93,27 +96,32 @@ proc fax_phonebook {} {
 
     frame $wn.l
     frame $wn.l.l
-    label $wn.l.l.1 -text "Fax Number" -width 20 -anchor w
-    label $wn.l.l.2 -text "Recipient"  -width 40 -anchor w -padx 4
-    pack $wn.l.l.1 $wn.l.l.2 -side left -fill x
-    text $wn.l.t -width 60 -height 10 -state disabled \
-         -tabs {5c left 15c left 25c left} -wrap none \
+    label $wn.l.l.1 -text $m(fax_number) -width 20 -anchor w
+    label $wn.l.l.2 -text $m(recipient)  -width 20 -anchor w -padx 4
+    label $wn.l.l.3 -text $m(reference)  -width 20 -anchor w -padx 4
+    label $wn.l.l.4 -text $m(description)  -width 20 -anchor w -padx 4
+    pack $wn.l.l.1 $wn.l.l.2  $wn.l.l.3 $wn.l.l.4 -side left -fill x
+    text $wn.l.t -width 80 -height 10 -state disabled \
+         -tabs {5c left 10c left 15c left} -wrap none \
          -xscroll "$wn.l.x set" -yscroll "$wn.l.y set" \
          -relief sunken -font $fax(f1)
+    mscroll $wn.l.t
     scrollbar $wn.l.x -command "$wn.l.t xview" -orient horizontal
     scrollbar $wn.l.y -command "$wn.l.t yview"
-    grid $wn.l.l  -row 0 -column 0 -rowspan 1 -columnspan 2 -sticky news
+    grid $wn.l.l  -row 0 -column 0 -rowspan 1 -columnspan 2 -sticky w
     grid $wn.l.t  -row 1 -column 0 -rowspan 1 -columnspan 1 -sticky news
     grid $wn.l.y  -row 1 -column 1 -rowspan 1 -columnspan 1 -sticky news
     grid $wn.l.x  -row 2 -column 0 -rowspan 1 -columnspan 1 -sticky news
+    grid rowconfigure $wn.l 1 -weight 1
+    grid columnconfigure $wn.l 0 -weight 1
 
     # Fax Entries and Add and Edit buttons
 
     frame $wn.i -bd 2 -relief ridge
-    label $wn.i.1 -text "Fax Number"  -anchor e -width 10
-    label $wn.i.2 -text "Recipient"   -anchor e -width 10
-    label $wn.i.3 -text "Reference"   -anchor e -width 10
-    label $wn.i.4 -text "Description" -anchor e -width 10
+    label $wn.i.1 -text $m(fax_number)  -anchor e -width 10
+    label $wn.i.2 -text $m(recipient)   -anchor e -width 10
+    label $wn.i.3 -text $m(reference)   -anchor e -width 10
+    label $wn.i.4 -text $m(description) -anchor e -width 10
     entry $wn.i.5 -textvariable fax(tmpnumber) \
           -width 20 -font $fax(f1) -fg $fax(c1)
     entry $wn.i.6 -textvariable fax(tmprecipient) \
@@ -122,15 +130,15 @@ proc fax_phonebook {} {
           -width 40 -font $fax(f1) -fg $fax(c1)
     entry $wn.i.8 -textvariable fax(tmpdescription) \
           -width 40 -font $fax(f1) -fg $fax(c1)
-    button $wn.i.a -text Clear   -command fax_pbook_faxnum_clear \
+    button $wn.i.a -text $m(clear)   -command fax_pbook_faxnum_clear \
            -width 6 -pady 0
-    button $wn.i.b -text Add     -command fax_pbook_faxnum_add \
+    button $wn.i.b -text $m(add)     -command fax_pbook_faxnum_add \
            -width 6 -pady 0
-    button $wn.i.c -text Replace -command fax_pbook_faxnum_replace \
+    button $wn.i.c -text $m(replace) -command fax_pbook_faxnum_replace \
            -width 6 -pady 0
-    button $wn.i.d -text Remove  -command fax_pbook_faxnum_remove \
+    button $wn.i.d -text $m(remove)  -command fax_pbook_faxnum_remove \
            -width 6 -pady 0
-    button $wn.i.e -text Sort    -command fax_pbook_faxnum_sort \
+    button $wn.i.e -text $m(sort)    -command fax_pbook_faxnum_sort \
            -width 6 -pady 0
     grid $wn.i.1  -row 1 -column 1 -rowspan 1 -columnspan 1 -sticky news
     grid $wn.i.2  -row 2 -column 1 -rowspan 1 -columnspan 1 -sticky news
@@ -145,19 +153,25 @@ proc fax_phonebook {} {
     grid $wn.i.c  -row 2 -column 6 -rowspan 1 -columnspan 1 -sticky news
     grid $wn.i.d  -row 3 -column 6 -rowspan 1 -columnspan 1 -sticky news
     grid $wn.i.e  -row 4 -column 6 -rowspan 1 -columnspan 1 -sticky news
+    grid columnconfigure $wn.i 2 -weight 1
 
     # Select and Close Buttons
 
     frame $wn.b -bd 10
-    button $wn.b.1 -text "Select Fax Number" \
-           -command fax_pbook_select_faxnumber \
-           -width 30 -pady 2
-    button $wn.b.3 -text Close -command fax_pbook_close -width 6 -pady 2
-    pack $wn.b.1 $wn.b.3 -side left -fill x -expand yes
+    button $wn.b.1 -text $m(select_fax_number) \
+           -command "fax_pbook_select_faxnumber; destroy $fax(phonebookwin)" \
+           -width 64 -pady 2
+    button $wn.b.2 -text $m(cancel) -command fax_pbook_cancel -pady 2
+    button $wn.b.3 -text $m(close) -command fax_pbook_close -pady 2
+    pack $wn.b.3 $wn.b.2 $wn.b.1 -side right -fill x -expand yes
 
     # Packing of all frames
 
-    pack $wn.0 $wn.g $wn.j $wn.x $wn.l $wn.i $wn.b -side top -fill x -expand yes
+    pack $wn.b $wn.i -side bottom -fill x
+    pack $wn.0    -side top -fill x 
+    pack $wn.g   -side top -fill both -expand yes
+    pack $wn.j    -side top -fill x 
+    pack $wn.l    -side top -fill both -expand yes
 
     # Set the globally accessed windows
 
@@ -182,11 +196,12 @@ proc fax_phonebook {} {
     bind $wn.j.4 <KeyPress-Up> {focus $fax(phonebookwin).j.3}
     bind $fax(numberlistwin) <Button-1>      fax_pbook_faxnum_setcur
     bind $fax(numberlistwin) <Button-3>      fax_pbook_faxnum_unsetcur
-    bind $fax(numberlistwin) <Double-Button> fax_pbook_select_faxnumber
+    bind $fax(numberlistwin) <Double-Button-1> fax_pbook_select_faxnumber
     bind $fax(grouplistwin)  <Button-1>      fax_pbook_group_setcur
     bind $fax(grouplistwin)  <Button-3>      fax_pbook_group_unsetcur
     bind $fax(grouplistwin)  <Double-Button> fax_pbook_select_group
 
+
     # Initialization
 
     set fax(curgroupname)		"All"
@@ -209,7 +224,7 @@ proc fax_pbook_read_faxnumberlist {} {
 # This procedure reads group list file into the variable fax(grouplist).
 # Then it reads each group file into the variable fax(group-$groupname).
 #
-    global fax
+    global fax m
 
     # Read group list into a variable fax(grouplist).
 
@@ -233,7 +248,7 @@ proc fax_pbook_read_faxnumberlist {} {
                 lappend fax(group-$groupname) "$line"
             }
         } else {
-            puts "TkFax: Fax list file $file does not exits."
+            puts "TkFax: Fax list file $file $m(does_not_exist)"
         }
     }
 
@@ -306,7 +321,7 @@ proc fax_pbook_group_clear {} {
 }
 
 proc fax_pbook_group_add {} {
-    global fax
+    global fax m
 
     # check groupname to see it is non-empty or already used.
 
@@ -314,15 +329,15 @@ proc fax_pbook_group_add {} {
     set replace 0
     if {$groupname==""} { return }
     if {$groupname=="All"} {
-        tk_messageBox -icon error -message "Group All is reserved." \
-            -type ok
+            set q [tk_dialog .dialog "TkFax Dialog" \
+                  "$m(group) All $m(is_reserved)"  {error} 0 $m(ok)]
         return
     }
     foreach igroup $fax(grouplist) {
         set igroupname [lindex [split $igroup \t] 0]
         if {$groupname==$igroupname} {
             set q [tk_dialog .dialog "TkFax Dialog" \
-                   "Group name $groupname is already used." {} 0 {OK}]
+                   "$m(group_name) $groupname $m(is_already_used)" {error} 0 $m(ok)]
             return
         }
     }
@@ -342,8 +357,8 @@ proc fax_pbook_group_add {} {
     set file $fax(pbookdir)/$groupname.pbd
     if [file exist $file] {
         set q [tk_dialog .dialog "TkFax Dialog" \
-  "Phone book database file $file already exists. Do you want to read it in?" \
-               {} 0 {Yes} {No}]
+  "$m(phone_book_database_file) $file $m(is_already_exists) $m(do_you_want_to_read_it_in)" \
+               {question} 0 $m(yes) $m(no) ]
         if {$q==0} {
             set fid [open $file r]
             while {[set line [gets $fid]]!={}} {
@@ -357,12 +372,14 @@ proc fax_pbook_group_add {} {
     focus $fax(phonebookwin).j.3
 }
 
+# 26 Sep 2001 modified by Masaki Shinomiya
 proc fax_pbook_group_remove {} {
-    global fax
-    set line [$fax(grouplistwin) get cur.first {cur.last -1 char}]
-    set groupname [lindex [split $line \t] 0]
-    if {$groupname=="All"} {
-        tk_messageBox -icon error -message "Group All cannot be removed." \
+    global fax m
+#    set line [$fax(grouplistwin) get cur.first {cur.last -1 char}]
+#    set groupname [lindex [split $line \t] 0]
+    set groupname $fax(tmpgroupname)
+    if {$groupname=="All" | $groupname=="Misc"} {
+        tk_messageBox -icon error -message "$m(group) $groupname $m(cannot_be_removed)" \
             -type ok
         return
     }
@@ -373,8 +390,8 @@ proc fax_pbook_group_remove {} {
     unset fax(group-$groupname)
     set file $fax(pbookdir)/$groupname.pbd
     set q [tk_dialog .dialog "TkFax Dialog" \
-           "Do you want to delete a phone book database file $file?" \
-           {} 0 {Yes} {No}]
+           "$m(do_you_want_to_delete_a_phone_book_database_file) $file?"\
+           {question} 0 $m(yes) $m(no) ]
     if {$q==0} {
         exec rm -f $file
     }
@@ -489,8 +506,14 @@ proc fax_pbook_faxnum_add {} {
 #
 # This adds a new fax number to the current group.
 #
-    global fax
-    if {$fax(tmpnumber) != {}} {
+    global fax m
+    set groupname $fax(curgroupname)
+   if {$fax(tmpnumber) == {} } {
+       set q [tk_dialog .dialog "TkFax Dialog" \
+                 $m(enter_fax_number)   {error} 0 $m(ok)]
+       return
+    }
+    if {$groupname== "All"} { set groupname "Misc" }
         $fax(numberlistwin) configure -state normal
         set line \
 "$fax(tmpnumber)\t$fax(tmprecipient)\t$fax(tmpreference)\t$fax(tmpdescription)"
@@ -501,17 +524,27 @@ proc fax_pbook_faxnum_add {} {
         }
         $fax(numberlistwin) yview end
         $fax(numberlistwin) configure -state disabled
-        lappend fax(group-$fax(curgroupname)) $line
-        fax_pbook_faxnum_clear
+        lappend fax(group-$groupname) $line
+             fax_message \
+                "Phone book: $m(fax_number) $m(is_registered_in) $groupname group."
+       fax_pbook_faxnum_clear
         focus $fax(phonebookwin).i.5
-    }
 }
 
+
 proc fax_pbook_faxnum_remove {} {
 #
+# 26 Sep 2001 error trap when no nummbers selected
 # This removes a fax number from the current group.
 #
-    global fax
+   global fax m
+   if { $fax(tmpnumber) ==  "" } { return 1 }
+   set groupname $fax(curgroupname)
+   if {$groupname == "All" || $groupname == ""} {
+        set q [tk_dialog .dialog "TkFax Dialog" \
+                "$m(select_group_other_than_all)"  {error} 0 $m(ok)]
+        return
+    } 
     $fax(numberlistwin) configure -state normal
     $fax(numberlistwin) delete cur.first cur.last
     $fax(numberlistwin) configure -state disabled
@@ -535,17 +568,28 @@ proc fax_pbook_faxnum_replace {} {
 #
 # This replaces the selected faxnumber with corrected info.
 #
-    global fax
+# 26 Sep 2001 error trap when no nummbers selected
+# 20 Sep 2001 check the group, replacing only one item
+    global fax m
+   if { $fax(tmpnumber) ==  "" } { return 1 }
+    set groupname $fax(curgroupname)
+    if {$groupname == "All" || $groupname == ""} {
+            set q [tk_dialog .dialog "TkFax Dialog" \
+                  "$m(select_group_other_than_all)"  {error} 0 $m(ok)]
+        return
+     } 
     $fax(numberlistwin) configure -state normal
     set insertpoint [$fax(numberlistwin) index cur.first]
     set endpoint [$fax(numberlistwin) index end]
     $fax(numberlistwin) delete cur.first cur.last
     set line \
 "$fax(tmpnumber)\t$fax(tmprecipient)\t$fax(tmpreference)\t$fax(tmpdescription)"
-    if {$insertpoint<[expr $endpoint-1]} {
+    if { $insertpoint < [expr $endpoint-1] } {
         $fax(numberlistwin) insert $insertpoint "$line\n"
-    } else {
+    } elseif { $insertpoint > 1 } {
         $fax(numberlistwin) insert $insertpoint "\n$line"
+    } else {
+        $fax(numberlistwin) insert $insertpoint "$line"
     }
     $fax(numberlistwin) configure -state disabled
     fax_pbook_reset_numberlist
@@ -555,12 +599,23 @@ proc fax_pbook_select_faxnumber {} {
 #
 # This selects current faxnumber for faxing.
 #
-    global fax
+    global fax m
     set fax(number)      $fax(tmpnumber)
     set fax(recipient)   $fax(tmprecipient)
     set fax(reference)   $fax(tmpreference)
     set fax(description) $fax(tmpdescription)
-    destroy $fax(phonebookwin)
+    if { $fax(number) == "" } {
+        set q [tk_dialog .dialog "TkFax Dialog" \
+                  "$m(no_fax_number_selected)"  {error} 0 $m(ok)]
+        return
+     } 
+#    destroy $fax(phonebookwin)
+}
+
+# 29 Sep 2001
+proc fax_pbook_cancel {} {
+    fax_pbook_read_faxnumberlist
+    fax_pbook_close
 }
 
 proc fax_pbook_close {} {
