@@ -2,9 +2,22 @@
 # StartUp
 #----------------------------------------------------------------
 
+# set locale and read messagess
+set fax(libdir) $c(libdir)
+set fax(progname) ""
+set fax(version) ""
+set fax(date) ""
+set fax(faxagent) ""
+set fax(locale) ""
+set fax(userconfigfile) ""
+set fax(pbookgroupfile) ""
+
+
 # Read files.
 
 set tkscan_files "
+	fax-about
+	fax-conf
         scan-about
 	scan-drivers/$scanner_driver
         scan-conf
@@ -17,18 +30,25 @@ set tkscan_files "
 "
 foreach i $tkscan_files { source $c(libdir)/$i.tcl }
 
+if { $fax(locale) == "" } { set fax(locale) "C" }
+if { $c(locale)=="" } { set c(locale) $fax(locale) }
+source $c(libdir)/msg_C.tcl
+if [file exists $c(libdir)/msg_$c(locale).tcl] {
+   source $c(libdir)/msg_$c(locale).tcl
+}
+
 # Let's start.
 
 eval destroy [winfo child .]
 wm title . "TkScan"
 
 set s(unit)	mm
-set s(premodecurrent) 0
 
 # The user configuration file, if exists, overwrites the above assignments.
 
 if [file exists $c(userconf)] {source $c(userconf)}
 
+
 # Initialization of some variables
 
 set s(nrect)	0
@@ -36,6 +56,7 @@ set s(runscan)	0
 set s(curscan)	0
 set s(stop)	0
 
+
 # Launch main window
 
 Window_Scan {}
